* [gentoo-commits] proj/linux-patches:genpatches-misc commit in: scripts/, web/
@ 2025-01-09 16:11 Mike Pagano
0 siblings, 0 replies; 4+ messages in thread
From: Mike Pagano @ 2025-01-09 16:11 UTC (permalink / raw
To: gentoo-commits
commit: a35ffbd498fee00163a30ea49c1f13d15c96d226
Author: Mike Pagano <mpagano <AT> gentoo <DOT> org>
AuthorDate: Thu Jan 9 16:11:35 2025 +0000
Commit: Mike Pagano <mpagano <AT> gentoo <DOT> org>
CommitDate: Thu Jan 9 16:11:35 2025 +0000
URL: https://gitweb.gentoo.org/proj/linux-patches.git/commit/?id=a35ffbd4
Fix broken rsyncing of tarballs
Signed-off-by: Mike Pagano <mpagano <AT> gentoo.org>
scripts/gpdoweb | 3 ++-
web/gentoo_sources_web.pm | 2 +-
2 files changed, 3 insertions(+), 2 deletions(-)
diff --git a/scripts/gpdoweb b/scripts/gpdoweb
index 2f734fd9..eb6fa1d4 100755
--- a/scripts/gpdoweb
+++ b/scripts/gpdoweb
@@ -11,6 +11,7 @@ fi
# send generated htm files for site
echo "calling rsync command: rsync --exclude=/trunk --exclude=/tarballs --delete -Cavze ssh ${WEB_LOCAL}/output/ ${USERNAME}@${WEB_GENPATCHES_BASE}"
+
rsync -P --exclude=/trunk --exclude=/tarballs --delete -Cavze ssh \
${WEB_LOCAL}/output/ ${USERNAME}@${WEB_GENPATCHES_BASE}
@@ -48,7 +49,7 @@ echo "rsync -avz -P ${USERNAME}@dev.gentoo.org:~${USERNAME}/public_html/dist/gen
rsync -avz -P ${USERNAME}@dev.gentoo.org:~${USERNAME}/public_html/dist/genpatches/${KERNEL_NAME}* ${WEB_LOCAL}/tarballs/
# easy again, copy local tarballs to public_html
-rsync -Cavze -P ssh ${WEB_LOCAL}/tarballs/ ${USERNAME}@${WEB_GENPATCHES_BASE}/tarballs
+rsync -Cavze -P ${WEB_LOCAL}/tarballs/ ${USERNAME}@${WEB_GENPATCHES_BASE}/tarballs
# remove linux-patches
rm -rf ${LOCAL_TMP}/linux-patches
diff --git a/web/gentoo_sources_web.pm b/web/gentoo_sources_web.pm
index a6b419a9..fbc4cc5a 100644
--- a/web/gentoo_sources_web.pm
+++ b/web/gentoo_sources_web.pm
@@ -35,7 +35,7 @@ $website_base = 'http://dev.gentoo.org/~mpagano/genpatches';
$git_root='/home/mike/gentoo/linux-patches';
$ebuild_base = '/usr/local/gentoo-x86'; # /usr/portage
-@kernels = ('sys-kernel/mips-sources','sys-kernel/pf-sources','sys-kernel/rt-sources','sys-kernel/gentoo-sources','sys-kernel/zen-sources');
+@kernels = ('sys-kernel/gentoo-kernel','sys-kernel/gentoo-kernel-bin','sys-kernel/mips-sources','sys-kernel/pf-sources','sys-kernel/rt-sources','sys-kernel/gentoo-sources','sys-kernel/zen-sources');
sub precheck {
^ permalink raw reply related [flat|nested] 4+ messages in thread
* [gentoo-commits] proj/linux-patches:genpatches-misc commit in: scripts/, web/
@ 2022-07-22 20:29 Alice Ferrazzi
0 siblings, 0 replies; 4+ messages in thread
From: Alice Ferrazzi @ 2022-07-22 20:29 UTC (permalink / raw
To: gentoo-commits
commit: 2b50d2b710993fb6946081d8705564c992a9aae1
Author: Alice Ferrazzi <alicef <AT> gentoo <DOT> org>
AuthorDate: Fri Jul 22 20:24:12 2022 +0000
Commit: Alice Ferrazzi <alicef <AT> gentoo <DOT> org>
CommitDate: Fri Jul 22 20:26:18 2022 +0000
URL: https://gitweb.gentoo.org/proj/linux-patches.git/commit/?id=2b50d2b7
Use USERNAME setting for set username on the email announcement
As we are getting the username from genpatchesrc use it for
the email web folder sent on the email announcement
Signed-off-by: Alice Ferrazzi <alicef <AT> gentoo.org>
scripts/gpdoemail | 2 +-
web/email-announcement.pl | 3 ++-
2 files changed, 3 insertions(+), 2 deletions(-)
diff --git a/scripts/gpdoemail b/scripts/gpdoemail
index 42f67c42..1b89c601 100755
--- a/scripts/gpdoemail
+++ b/scripts/gpdoemail
@@ -12,7 +12,7 @@ email="${ECHANGELOG_USER#*<}"
email="${email%>}"
cd ${WEB_LOCAL}
-perl email-announcement.pl $1 ${KERNEL_NAME} ${LOCAL_TMP} ${REMOTE_BASE} |
+perl email-announcement.pl $1 ${KERNEL_NAME} ${LOCAL_TMP} ${REMOTE_BASE} ${name} |
${SENDMAIL} -F \"${name}\" -f \"${email}\" gentoo-kernel@lists.gentoo.org
diff --git a/web/email-announcement.pl b/web/email-announcement.pl
index 011e15fe..b921f732 100755
--- a/web/email-announcement.pl
+++ b/web/email-announcement.pl
@@ -8,6 +8,7 @@ $tag = shift;
$kernel_name = shift;
$LOCAL_TMP = shift;
$REMOTE_BASE = shift;
+$USERNAME = shift;
if ($tag =~ m/(2\.6\.\d+)-(\d+)/) {
$ver = $1;
@@ -20,7 +21,7 @@ else { # support for kernels >= 3.0
}
$have_history = 0;
-$website_base = 'http://dev.gentoo.org/~mpagano/genpatches';
+$website_base = 'http://dev.gentoo.org/~'.${USERNAME}.'/genpatches';
$result = `rm -rf ${LOCAL_TMP}/linux-patches`;
$result = `cd $LOCAL_TMP`;
^ permalink raw reply related [flat|nested] 4+ messages in thread
* [gentoo-commits] proj/linux-patches:genpatches-misc commit in: scripts/, web/
@ 2014-06-25 23:23 Mike Pagano
0 siblings, 0 replies; 4+ messages in thread
From: Mike Pagano @ 2014-06-25 23:23 UTC (permalink / raw
To: gentoo-commits
commit: 4c351394ebdcabafe794708f1f50def97f11c18c
Author: Mike Pagano <mpagano <AT> gentoo <DOT> org>
AuthorDate: Wed Jun 25 23:23:36 2014 +0000
Commit: Mike Pagano <mpagano <AT> gentoo <DOT> org>
CommitDate: Wed Jun 25 23:23:36 2014 +0000
URL: http://git.overlays.gentoo.org/gitweb/?p=proj/linux-patches.git;a=commit;h=4c351394
Fixes for gpdoemail and email-announcement.pl
---
scripts/gpdoemail | 2 +-
web/email-announcement.pl | 22 +++++++++++++++-------
2 files changed, 16 insertions(+), 8 deletions(-)
diff --git a/scripts/gpdoemail b/scripts/gpdoemail
index 558c320..42f67c4 100755
--- a/scripts/gpdoemail
+++ b/scripts/gpdoemail
@@ -12,7 +12,7 @@ email="${ECHANGELOG_USER#*<}"
email="${email%>}"
cd ${WEB_LOCAL}
-perl email-announcement.pl $1 ${KERNEL_NAME} |
+perl email-announcement.pl $1 ${KERNEL_NAME} ${LOCAL_TMP} ${REMOTE_BASE} |
${SENDMAIL} -F \"${name}\" -f \"${email}\" gentoo-kernel@lists.gentoo.org
diff --git a/scripts/gpdorelease b/scripts/gpdorelease
index 4625190..bec5650 100755
--- a/scripts/gpdorelease
+++ b/scripts/gpdorelease
@@ -117,4 +117,4 @@ scp /tmp/${TARBALL_BASENAME}-$newfullver.* ${USERNAME}@dev.gentoo.org:/space/dis
# gpdoweb
#fi
-#[[ ${DO_EMAIL_ANNOUNCEMENT} == "yes" ]] && gpdoemail $newfullver $KERNEL_NAME
+[[ ${DO_EMAIL_ANNOUNCEMENT} == "yes" ]] && gpdoemail $newfullver $KERNEL_NAME
diff --git a/web/email-announcement.pl b/web/email-announcement.pl
index 573c59a..d618c58 100755
--- a/web/email-announcement.pl
+++ b/web/email-announcement.pl
@@ -1,8 +1,8 @@
#!/usr/bin/perl
-# Copyright 2005 Gentoo Foundation; Distributed under the GPL v2
+# Copyright 2014 Gentoo Foundation; Distributed under the GPL v2
use Cwd;
-use gentoo_sources_web;
+#use gentoo_sources_web;
$tag = shift;
$kernel_name = shift;
@@ -20,54 +20,96 @@ else { # support for kernels >= 3.0
$have_history = 0;
# Try and find previous release
+
if ($rel > 1) {
$oldtag = $ver.'-'.($rel-1);
- $cmd = 'svn log -q --stop-on-copy '.$subversion_root.'/tags/'.$oldtag;
- @log_lines = `$cmd`;
- $lastrev = 0;
- foreach (@log_lines) {
- next if $_ !~ /^r(\d+) \|/;
- $lastrev = $1;
- last;
- }
-}
+ $cmd='git -C '.${LOCAL_PATCHES_TRUNK}.' rev-list '.$oldtag;
+ @output = `$cmd`;
+
+ foreach $line (@output) {
+ $have_history = 1;
+ if (index($line, "fatal") != -1) {
+ $have_history =0;
+ }
+ if ($have_history == 0) {
+ break;
+ }
+ }
+
-if ($lastrev) {
- @commits = _parse_log($tag, $lastrev);
- $have_history = @commits;
+
+ if ($have_history == 1) {
+ $cmd='git --no-pager -C '.${LOCAL_PATCHES_TRUNK}.' log --pretty=format:"%s (%an)" --name-status '.$oldtag.'..'.$tag;
+ @log_lines = `$cmd`;
+ $have_history = 1;
+ }
+ else {
+ $cmd='git --no-pager -C '.${LOCAL_PATCHES_TRUNK}.' log --pretty=format:"%s (%an)" --name-status '.$tag;
+ @log_lines = `$cmd`;
+ }
}
-local $ext;
-$ext = get_tarball_ext($tag);
+#if ($rel > 1) {
+# $oldtag = $ver.'-'.($rel-1);
+# #$cmd = 'svn log -q --stop-on-copy '.$subversion_root.'/tags/'.$oldtag;
+# #$cmd = 'svn log -q --stop-on-copy '.$subversion_root.'/tags/'.$oldtag;
+#
+# # check out branch
+# printf("LOCAL_PATCHES_TRUNK is ${LOCAL_PATCHES_TRUNK}\n");
+# $cmd='git -C '.${LOCAL_PATCHES_TRUNK}.' checkout '.$ver;
+# @result = `$cmd`;
+#
+# # get log in between tags
+# $cmd='git -C '.${LOCAL_PATCHES_TRUNK}.' log '.$oldtag.'..'.$tag.' --name-status';
+# printf (" cmd is $cmd\n");
+#
+# @log_lines = `$cmd`;
+# $lastrev = 0;
+# foreach (@log_lines) {
+# next if $_ !~ /^r(\d+) \|/;
+# $lastrev = $1;
+# last;
+# }
+#}
+#
+#printf("lastrev is $lastrev\n");
+#
+#if ($lastrev) {
+# printf("inside lastrev\n");
+# @commits = _parse_log($tag, $lastrev);
+# $have_history = @commits;
+#}
+#
+#local $ext;
+#$ext = get_tarball_ext($tag);
+#
$email .= "To: Gentoo Kernel List <gentoo-kernel\@lists.gentoo.org>\n";
$email .= "Subject: [ANNOUNCE] $kernel_name-$tag release\n";
$email .= "\nThis is an automated email announcing the release of $kernel_name-$tag\n\n";
-if ($lastrev && $have_history) {
+if ($have_history) {
$email .= "\nCHANGES SINCE $oldtag\n";
+}
+else {
+ $email .= "\nCHANGES\n";
+}
$email .= "-----------------------\n\n";
- foreach $rev (@commits) {
- next if !$rev->{'rev'};
- chomp $rev->{'logmsg'};
- $email .= 'Revision '.$rev->{'rev'}.': ';
- $email .= $rev->{'logmsg'}.' ('.$rev->{'author'}.')'."\n";
- $email .= 'Added: '.$_."\n" foreach (@{$rev->{'actionA'}});
- $email .= 'Modified: '.$_."\n" foreach (@{$rev->{'actionM'}});
- $email .= 'Deleted: '.$_."\n" foreach (@{$rev->{'actionD'}});
- $email .= "\n";
+ foreach $line (@log_lines) {
+ if (index($line, "0000_README") == -1) {
+ $email .= "$line";
+ }
}
-}
-$email .= "\nPATCHES\n";
-$email .= "-------\n\n";
-$email .= "When the website updates, the complete patch list and split-out patches will be\n";
-$email .= "available here:\n";
-$email .= $website_base."/patches-".$tag.".htm\n";
-$email .= $website_base."/tarballs/".$kernel_name."-".$tag.".base.tar".$ext."\n";
-$email .= $website_base."/tarballs/".$kernel_name."-".$tag.".extras.tar".$ext."\n";
-$email .= $website_base."/tarballs/".$kernel_name."-".$tag.".experimental.tar".$ext."\n";
+#$email .= "\nPATCHES\n";
+#$email .= "-------\n\n";
+#$email .= "When the website updates, the complete patch list and split-out patches will be\n";
+#$email .= "available here:\n";
+#$email .= $website_base."/patches-".$tag.".htm\n";
+#$email .= $website_base."/tarballs/".$kernel_name."-".$tag.".base.tar".$ext."\n";
+#$email .= $website_base."/tarballs/".$kernel_name."-".$tag.".extras.tar".$ext."\n";
+#$email .= $website_base."/tarballs/".$kernel_name."-".$tag.".experimental.tar".$ext."\n";
if ($kernel_name == "genpatches") {
$email .= "\n\nABOUT GENPATCHES\n";
^ permalink raw reply related [flat|nested] 4+ messages in thread
end of thread, other threads:[~2025-01-09 16:12 UTC | newest]
Thread overview: 4+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2025-01-09 16:11 [gentoo-commits] proj/linux-patches:genpatches-misc commit in: scripts/, web/ Mike Pagano
-- strict thread matches above, loose matches on Subject: below --
2022-07-22 20:29 Alice Ferrazzi
2014-06-25 23:23 Mike Pagano
2014-06-24 16:47 Mike Pagano
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff --git a/web/email-announcement.pl b/web/email-announcement.pl
index d618c58..53d6f95 100755
--- a/web/email-announcement.pl
+++ b/web/email-announcement.pl
@@ -6,6 +6,8 @@ use Cwd;
$tag = shift;
$kernel_name = shift;
+$LOCAL_TMP = shift;
+$REMOTE_BASE = shift;
if ($tag =~ m/(2\.6\.\d+)-(\d+)/) {
$ver = $1;
@@ -19,11 +21,17 @@ else { # support for kernels >= 3.0
$have_history = 0;
-# Try and find previous release
+$result = `cd $LOCAL_TMP`;
+$result = `git -C ${LOCAL_TMP}/linux-patches reset`;
+$result = `git clone $REMOTE_BASE ${LOCAL_TMP}/linux-patches`;
+
+# checkout branch
+$result = `git -C ${LOCAL_TMP}/linux-patches checkout ${tag}`;
+# Try and find previous release
if ($rel > 1) {
$oldtag = $ver.'-'.($rel-1);
- $cmd='git -C '.${LOCAL_PATCHES_TRUNK}.' rev-list '.$oldtag;
+ $cmd='git -C '.${LOCAL_TMP}.'/linux-patches rev-list '.$oldtag;
@output = `$cmd`;
foreach $line (@output) {
@@ -39,12 +47,12 @@ if ($rel > 1) {
if ($have_history == 1) {
- $cmd='git --no-pager -C '.${LOCAL_PATCHES_TRUNK}.' log --pretty=format:"%s (%an)" --name-status '.$oldtag.'..'.$tag;
+ $cmd='git --no-pager -C '.${LOCAL_TMP}.'/linux-patches log --pretty=format:"%s (%an)" --name-status '.$oldtag.'..'.$tag;
@log_lines = `$cmd`;
$have_history = 1;
}
else {
- $cmd='git --no-pager -C '.${LOCAL_PATCHES_TRUNK}.' log --pretty=format:"%s (%an)" --name-status '.$tag;
+ $cmd='git --no-pager -C '.${LOCAL_TMP}.'/linux-patches log --pretty=format:"%s (%an)" --name-status '.$tag;
@log_lines = `$cmd`;
}
}
@@ -56,12 +64,12 @@ if ($rel > 1) {
# #$cmd = 'svn log -q --stop-on-copy '.$subversion_root.'/tags/'.$oldtag;
#
# # check out branch
-# printf("LOCAL_PATCHES_TRUNK is ${LOCAL_PATCHES_TRUNK}\n");
-# $cmd='git -C '.${LOCAL_PATCHES_TRUNK}.' checkout '.$ver;
+# printf("LOCAL_TMP is ${LOCAL_TMP}\n");
+# $cmd='git -C '.${LOCAL_TMP}.' checkout '.$ver;
# @result = `$cmd`;
#
# # get log in between tags
-# $cmd='git -C '.${LOCAL_PATCHES_TRUNK}.' log '.$oldtag.'..'.$tag.' --name-status';
+# $cmd='git -C '.${LOCAL_TMP}.' log '.$oldtag.'..'.$tag.' --name-status';
# printf (" cmd is $cmd\n");
#
# @log_lines = `$cmd`;
^ permalink raw reply related [flat|nested] 4+ messages in thread
* [gentoo-commits] proj/linux-patches:genpatches-misc commit in: scripts/, web/
@ 2014-06-24 16:47 Mike Pagano
0 siblings, 0 replies; 4+ messages in thread
From: Mike Pagano @ 2014-06-24 16:47 UTC (permalink / raw
To: gentoo-commits
commit: 3eafe7fb22fbe3f85a32801db33aea94f05de1e7
Author: Mike Pagano <mpagano <AT> gentoo <DOT> org>
AuthorDate: Tue Jun 24 16:46:58 2014 +0000
Commit: Mike Pagano <mpagano <AT> gentoo <DOT> org>
CommitDate: Tue Jun 24 16:46:58 2014 +0000
URL: http://git.overlays.gentoo.org/gitweb/?p=proj/linux-patches.git;a=commit;h=3eafe7fb
Add back sending announcement email. Add fixed email perl script.
---
scripts/gpdorelease | 2 +-
web/email-announcement.pl | 112 +++++++++++++++++++++++++++++++---------------
2 files changed, 78 insertions(+), 36 deletions(-)